# Calcbench API Client

A Python client for Calcbench's API.

Calcbench is an interface to the XBRL encoded 10-(K|Q) documents public companies file on the SEC's Edgar system.

    >>>import calcbench as cb
    >>>cb.standardized_data(entire_universe=True,
                            all_history=True,
                            metrics=['Assets', 'AssetRetirementObligation'],
                            period_type='annual')

## Documentation

http://calcbench.github.io/python_api_client/html/index.html

## Installation

    pip install calcbench-api-client

## Credentials

Use your Calcbench username (email) and password. Get a free two week Calcbench trial @ https://www.calcbench.com/join.

## Examples

https://github.com/calcbench/notebooks.

## Support

andrew@calcbench.com

## Credit

@someben https://github.com/calcbench/python_api_client/commit/6c2312525fa365acc91bd8e979037fc2492845f3
